"""
    Library specific information.
"""

__title__ = "gatey-sdk"
__description__ = "Python client for Gatey (https://gatey.florgon.com)"
__url__ = "https://github.com/florgon/gatey-sdk-py"
__version__ = "0.0.9"
__author__ = "Florgon Team and Contributors"
__author_email__ = "support@florgon.com"
__license__ = "MIT"
__copyright__ = "Copyright 2022 Florgon Solutions"
